OAuth2Response class

Represents the base response for the OAuth 2 requests. see https://tools.ietf.org/html/rfc6749#section-5.2

Implementers

Constructors

OAuth2Response({Map<String, dynamic> respMap = const {}, Exception? exception, StackTrace? stackTrace})
OAuth2Response.errorResponse({int httpStatusCode = 404, String? error, String? errorDescription, String? errorUri, Exception? exception, StackTrace? stackTrace})
OAuth2Response.fromHttpResponse(Response response)
factory
OAuth2Response.fromMap(Map<String, dynamic> respMap, {Exception? exception, StackTrace? stackTrace})

Properties

error String?
no setter
errorDescription String?
no setter
errorUri String?
no setter
exception Exception?
final
hashCode int
The hash code for this object.
no setterinherited
httpStatusCode int
no setter
respMap Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
final

Methods

getRespField(String fieldName) → dynamic
isValid() bool
Checks if the access token request returned a valid status code
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited